@@ -33,17 +33,36 @@ public final class UploadProgressPanel extends Composite {
 		initWidget(mainPanel);
 	}
 	
+	/**
+	 * Used when attaching files via button
+	 * @return
+	 */
 	public FileUpload initialize() {	
 		mainPanel.clear();
-		fileSubmit = new FileSubmit(eventBus);
+		fileSubmit = new FileSubmit(eventBus, false);
 		mainPanel.add(fileSubmit);
 		mainPanel.add(new UploadProgress());
 		//return the fileupload so that you cane set it hidden
 		return fileSubmit.getFileUpload();
 	}
+	
+	/**
+	 * Used when attaching files via dnd
+	 * @return
+	 */
+	public void initializeDND(){
+		mainPanel.clear();
+		fileSubmit = new FileSubmit(eventBus, true);
+		mainPanel.add(fileSubmit);
+		mainPanel.add(new UploadProgress());
+	}
 
 	public void showRegisteringResult(boolean result) {
-		fileSubmit.showRegisteringResult(result);
+		fileSubmit.showRegisteringResult(result, null);
+	}
+	
+	public void showRegisteringResult(boolean result, String customFeedback) {
+		fileSubmit.showRegisteringResult(result, customFeedback);
 	}
 	
 	public FileUpload getFileUpload() {
